@@ -55,20 +55,36 @@ class MockPopen(object):
             def __exit__(self, exc_type, exc_val, exc_tb):
                 inst.wait()
                 for stream in inst.stdout, inst.stderr:
-                    stream.close()
+                    if stream:
+                        stream.close()
 
             inst.__exit__ = __exit__
 
+    def _resolve_behaviour(self, stdout, stderr, returncode,
+                           pid, poll_count, behaviour):
+        if behaviour is None:
+            return PopenBehaviour(
+                stdout, stderr, returncode, pid, poll_count
+            )
+        else:
+            return behaviour
+
     def set_command(self, command, stdout=b'', stderr=b'', returncode=0,
-                    pid=1234, poll_count=3):
+                    pid=1234, poll_count=3, behaviour=None):
         """
         Set the behaviour of this mock when it is used to simulate the
         specified command.
 
         :param command: A string representing the command to be simulated.
+
+        If supplied, ``behaviour`` must be either a :class:`PopenBehaviour`
+        instance or a callable that takes the ``command`` string representing
+        the command to be simulated and the ``stdin`` for that command and
+        returns a :class:`PopenBehaviour` instance.
         """
-        self.commands[command] = PopenBehaviour(stdout, stderr, returncode,
-                                                pid, poll_count)
+        self.commands[command] = self._resolve_behaviour(
+            stdout, stderr, returncode, pid, poll_count, behaviour
+        )
 
     def set_default(self, stdout=b'', stderr=b'', returncode=0,
                     pid=1234, poll_count=3, behaviour=None):
@@ -82,12 +98,9 @@ class MockPopen(object):
         the command to be simulated and the ``stdin`` for that command and
         returns a :class:`PopenBehaviour` instance.
         """
-        if behaviour is None:
-            self.default_behaviour = PopenBehaviour(
-                stdout, stderr, returncode, pid, poll_count
-            )
-        else:
-            self.default_behaviour = behaviour
+        self.default_behaviour = self._resolve_behaviour(
+            stdout, stderr, returncode, pid, poll_count, behaviour
+        )
 
     def __call__(self, *args, **kw):
         return self.mock.Popen(*args, **kw)
@@ -142,20 +155,35 @@ class MockPopen(object):
 
         self.mock.Popen_instance.pid = behaviour.pid
         self.mock.Popen_instance.returncode = None
+        if PY3:
+            self.mock.Popen_instance.args = args
 
         return self.mock.Popen_instance
 
-    def wait(self):
-        "Simulate calls to :meth:`subprocess.Popen.wait`"
-        self.mock.Popen_instance.returncode = self.returncode
-        return self.returncode
+    if PY3:
+        def wait(self, timeout=None):
+            "Simulate calls to :meth:`subprocess.Popen.wait`"
+            self.mock.Popen_instance.returncode = self.returncode
+            return self.returncode
 
-    def communicate(self, input=None):
-        "Simulate calls to :meth:`subprocess.Popen.communicate`"
-        self.wait()
-        i = self.mock.Popen_instance
-        return (i.stdout and i.stdout.read(),
-                i.stderr and i.stderr.read())
+        def communicate(self, input=None, timeout=None):
+            "Simulate calls to :meth:`subprocess.Popen.communicate`"
+            self.wait()
+            i = self.mock.Popen_instance
+            return (i.stdout and i.stdout.read(),
+                    i.stderr and i.stderr.read())
+    else:
+        def wait(self):
+            "Simulate calls to :meth:`subprocess.Popen.wait`"
+            self.mock.Popen_instance.returncode = self.returncode
+            return self.returncode
+
+        def communicate(self, input=None):
+            "Simulate calls to :meth:`subprocess.Popen.communicate`"
+            self.wait()
+            i = self.mock.Popen_instance
+            return (i.stdout and i.stdout.read(),
+                    i.stderr and i.stderr.read())
 
     def poll(self):
         "Simulate calls to :meth:`subprocess.Popen.poll`"
