@@ -1,4 +1,4 @@
-from datetime import date
+from datetime import date, datetime
 
 from functools import partial
 
@@ -69,7 +69,10 @@ class TestCompare(CompareHelper, TestCase):
         compare(o, o)
 
     def test_object_diff(self):
-        compare(object(), object())
+        self.check_raises(
+            object(), object(),
+            '<object object at ...> != <object object at ...>'
+        )
 
     def test_different_types(self):
         self.check_raises('x', 1, "'x' != 1")
@@ -97,6 +100,43 @@ class TestCompare(CompareHelper, TestCase):
             expected
             )
 
+    def test_bytes_different(self):
+        if PY2:
+            expected = (
+                "\n" 
+                "'12345678901'\n"
+                '!=\n'
+                "'12345678902'"
+            )
+        else:
+            expected = (
+                "\n" 
+                "b'12345678901'\n"
+                '!=\n'
+                "b'12345678902'"
+            )
+        self.check_raises(
+            BytesLiteral('12345678901'),
+            BytesLiteral('12345678902'),
+            expected
+            )
+
+    def test_bytes_same_strict(self):
+        compare(actual=b'', expected=b'', strict=True)
+
+    if PY3:
+        def test_moar_bytes_different(self):
+            self.check_raises(
+                actual=b'{"byte_pound":"b\'\\\\xa3\'"}',
+                expected=b'{"byte_pound":"b\\\'\\xa3\'"}',
+                message = (
+                    "\n"
+                    "b'{\"byte_pound\":\"b\\\\\\'\\\\xa3\\\'\"}' (expected)\n"
+                    '!=\n'
+                    "b'{\"byte_pound\":\"b\\\'\\\\\\\\xa3\\\'\"}' (actual)"
+                )
+            )
+
     def test_string_diff_short(self):
         self.check_raises(
             '\n'+('x'*9), '\n'+('y'*9),
@@ -1532,3 +1572,17 @@ b
             'attributes differ:\n'
             "'y': 2 != 3"
         )
+
+    def test_empty_sets(self):
+        compare(set(), set())
+
+    def test_empty_sets_strict(self):
+        compare(set(), set(), strict=True)
+
+    def test_datetime_not_equal(self):
+        self.check_raises(
+            datetime(2001, 1, 1),
+            datetime(2001, 1, 2),
+            "datetime.datetime(2001, 1, 1, 0, 0) != "
+            "datetime.datetime(2001, 1, 2, 0, 0)"
+        )
